@@ -2,9 +2,9 @@
 
 use interoptopus::lang::c::{CType, CompositeType, Field, PrimitiveType};
 use interoptopus::lang::rust::CTypeInfo;
-use interoptopus::patterns::ascii_pointer::AsciiPointer;
 use interoptopus::patterns::slice::FFISlice;
-use interoptopus::{callback, ffi_type};
+use interoptopus::patterns::string::AsciiPointer;
+use interoptopus::{callback, ffi_surrogates, ffi_type};
 use std::fmt::Debug;
 use std::marker::PhantomData;
 
@@ -77,7 +77,7 @@ pub struct StructRenamedXYZ {
     pub e: EnumRenamedXYZ,
 }
 
-#[ffi_type(unsafe, skip(p))]
+#[ffi_type(skip(p))]
 #[repr(C)]
 pub struct Phantom<'a, T>
 where
@@ -97,7 +97,8 @@ pub struct Vec3f32 {
     pub z: f32,
 }
 
-#[ffi_type(unsafe, surrogates(foreign1 = "some_foreign_type", foreign2 = "some_foreign_type"))]
+#[ffi_type]
+#[ffi_surrogates(foreign1 = "some_foreign_type", foreign2 = "some_foreign_type")]
 #[repr(C)]
 pub struct Container {
     pub foreign1: SomeForeignType,
